/*
*  
*  $Id: iherramientascore.h 4478 2011-12-13 11:55:00Z carlos $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma once
// UIDs de las herramientas core: Reservado desde 0 a 100;

#define HCore_Puntero            1
#define HCore_Regla              3
#define HCore_Angulo             4
#define HCore_Lupa               5
#define HCore_Varita             6
#define HCore_LazoChroma         7
#define HCore_Elevacion          8
#define HCore_Nota               9
#define HCore_Deshacer	         10
#define HCore_LayoutVentana	     11
#define HCore_EdicionDICOM       12
#define HCore_Calibrado		     13
#define HCore_Debug              14
#define HCore_Marcado            15
#define HCore_Rejilla		     16
#define HCore_AnotacionesEsquina 17
#define HCore_PanelTags			 18
#define HCore_Reset              19
#define HCore_Desencajar         20
#define HCore_Interpolate        21

#define HCore_Pan                22
#define HCore_Zoom               23
#define HCore_Slider             24
#define HCore_WindowLevel        25

#define SubFamiliaEdicionDeshacer 0
//layout desencajar, anotaciones esquina...
#define SubFamiliaImagenDisposicion 1
//window level, mapas de color...
#define SubFamiliaImagenHerramientasRadio 2
